@@ -1,5 +1,5 @@
 // Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -9,12 +9,13 @@
 #include "iconbutton.h"
 
 // dtk
-#include <DPaletteHelper>
 
 // qt
 #include <QDebug>
 #include <QApplication>
+#include <QLoggingCategory>
 
+Q_DECLARE_LOGGING_CATEGORY(views)
 // 不同布局模式配置
 const int s_ItemHeight = 60;
 const QMargins s_ItemIconContentMargins = {8, 8, 8, 8};
@@ -36,6 +37,7 @@ ItemWidget::ItemWidget(ItemFuncType itemType, QWidget *parent)
     , m_funcButton(new IconButton(this))
     , m_functType(itemType)
 {
+    qCDebug(views) << "Enter ItemWidget::ItemWidget";
     showBackground = (itemType != ItemFuncType_GroupLabel && itemType != ItemFuncType_ItemLabel);
 
     /******** Add by ut001000 renfeixiang 2020-08-13:增加 Begin***************/
@@ -59,11 +61,14 @@ ItemWidget::ItemWidget(ItemFuncType itemType, QWidget *parent)
     m_funcButton->installEventFilter(this);
     installEventFilter(this);
     /***add end by ut001121***/
+    qCDebug(views) << "ItemWidget constructor finished";
 }
 
 ItemWidget::~ItemWidget()
 {
+    qCDebug(views) << "Enter ItemWidget::~ItemWidget";
     if (nullptr != m_moveSource) {
+        qCDebug(views) << "Branch: m_moveSource is not null, deleting";
         delete m_moveSource;
         m_moveSource = nullptr;
     }
@@ -71,12 +76,14 @@ ItemWidget::~ItemWidget()
 
 void ItemWidget::setIcon(const QString &icon)
 {
+    qCDebug(views) << "Enter ItemWidget::setIcon";
     m_iconButton->setIcon(QIcon::fromTheme(icon));
     m_iconButton->setIconSize(QSize(44, 44));
 }
 
 void ItemWidget::setFuncIcon(ItemFuncType iconType)
 {
+    qCDebug(views) << "Enter ItemWidget::setFuncIcon";
     // 统一设置大小
     m_funcButton->setIconSize(QSize(20, 20));
     m_deleteButton->setIconSize(QSize(20, 20));
@@ -90,20 +97,19 @@ void ItemWidget::setFuncIcon(ItemFuncType iconType)
     case ItemFuncType_UngroupedItem:
         m_funcButton->hide();
         m_deleteButton->hide();
-        break;
-    default:
-        break;
     }
 
 }
 
 ItemFuncType ItemWidget::getFuncType()
 {
+    // qCDebug(views) << "Enter ItemWidget::getFuncType";
     return m_functType;
 }
 
 void ItemWidget::setText(const QString &firstline, const QString &secondline)
 {
+    // qCDebug(views) << "Enter ItemWidget::setText";
     // 第一行信息 唯一值
     m_firstText = firstline;
     m_firstline->setText(firstline);
@@ -111,29 +117,30 @@ void ItemWidget::setText(const QString &firstline, const QString &secondline)
     // 第二行信息
     switch (m_functType) {
     case ItemFuncType_Item:
+        qCDebug(views) << "Branch: ItemFuncType_Item";
     case ItemFuncType_UngroupedItem:
         // 输入的第二行信息
         m_secondText = secondline;
         break;
-    case ItemFuncType_Group:{
+    case ItemFuncType_Group:
+        qCDebug(views) << "Branch: ItemFuncType_Group";
         // 第二行 组内服务器个数
         int serverCount = ServerConfigManager::instance()->getServerCount(firstline);
         if (serverCount <= 0) {
-            qInfo() << "get error count " << serverCount;
+            qCWarning(views) << "get error count " << serverCount;
             serverCount = 0;
         }
         m_secondText = QString("%1 server").arg(serverCount);
         break;
     }
-    default:
-        break;
-    }
     // 设置第二行信息
     m_secondline->setText(m_secondText);
+    qCDebug(views) << "ItemWidget::setText finished";
 }
 
 const QString ItemWidget::getFirstText() const
 {
+    // qCDebug(views) << "Enter ItemWidget::getFirstText";
     return m_firstText;
 }
 
@@ -149,12 +156,14 @@ bool ItemWidget::isChecked() const
 
 bool ItemWidget::isEqual(ItemFuncType type, const QString &key)
 {
+    // qCDebug(views) << "Enter ItemWidget::isEqual";
     // fistText是唯一值
     return ((type == m_functType) && (key == m_firstText));
 }
 
 void ItemWidget::getFocus()
 {
+    // qCDebug(views) << "Enter ItemWidget::getFocus";
     m_isFocus = true;
     // 项显示功能键
     if (ItemFuncType_Item == m_functType || ItemFuncType_Group == m_functType) {
@@ -162,10 +171,12 @@ void ItemWidget::getFocus()
         m_deleteButton->show();
         qInfo() << "edit button show";
     }
+    // qCDebug(views) << "ItemWidget::getFocus finished";
 }
 
 void ItemWidget::lostFocus()
 {
+    // qCDebug(views) << "Enter ItemWidget::lostFocus";
     m_isFocus = false;
     // 项影藏功能键
     if ((ItemFuncType_Item == m_functType || ItemFuncType_Group == m_functType) && (!m_isHover)) {
@@ -176,20 +187,26 @@ void ItemWidget::lostFocus()
 
 bool operator >(const ItemWidget &item1, const ItemWidget &item2)
 {
+    // qCDebug(views) << "Enter ItemWidget::operator >";
     // item1 item2都是组 或 item1 item2 都不是组
     if (item1.m_functType == item2.m_functType) {
+        qCDebug(views) << "Branch: same function type, comparing text";
         // 比较文字
         if (QString::compare(item1.m_firstText, item2.m_firstText) < 0) {
+            qCDebug(views) << "Branch: text comparison < 0";
             // 小于 0 例:ab bc
             return true;
         } else {
+            qCDebug(views) << "Branch: text comparison >= 0";
             // 其他情况
             return false;
         }
     } else if (item1.m_functType > item2.m_functType) {
+        qCDebug(views) << "Branch: item1 function type > item2 function type";
         // item1 是组 1 item2不是 0
         return true;
     } else {
+        qCDebug(views) << "Branch: item1 function type < item2 function type";
         // item1 不是组 0 item2是 1
         return false;
     }
@@ -197,13 +214,17 @@ bool operator >(const ItemWidget &item1, const ItemWidget &item2)
 
 bool operator <(const ItemWidget &item1, const ItemWidget &item2)
 {
+    // qCDebug(views) << "Enter ItemWidget::operator <";
     return !(item1 > item2);
 }
 
 void ItemWidget::onFuncButtonClicked()
 {
+    qCDebug(views) << "ItemWidget::onFuncButtonClicked() entered";
+
     /***add begin by ut001121 zhangmeng 20200924 判断移动事件来源 修复BUG48618***/
     if (m_moveSource) {
+        qCDebug(views) << "Branch: m_moveSource exists, returning";
         m_moveSource = nullptr;
         return ;
     }
@@ -212,16 +233,19 @@ void ItemWidget::onFuncButtonClicked()
     // 判断类型执行操作
     switch (m_functType) {
     case ItemFuncType_Group:
+        qCDebug(views) << "Branch: ItemFuncType_Group";
         // 显示分组
-        qInfo() << "group show" << m_firstText;
+        qCInfo(views) << "group show" << m_firstText;
         // 第一个参数是分组名，第二个参数是当前是否有焦点
         emit groupModify(m_firstText, m_isFocus);
         break;
     case ItemFuncType_Item: {
+        qCDebug(views) << "Branch: ItemFuncType_Item";
         // 修改项
-        qInfo() << "modify item" << m_firstText;
+        qCInfo(views) << "modify item" << m_firstText;
         bool isFocusOn = false;
         if (m_funcButton->hasFocus() || m_isFocus) {
+            qCDebug(views) << "Branch: button has focus or item has focus";
             // 焦点在大框或者编辑按钮上
             isFocusOn = true;
         }
@@ -229,15 +253,20 @@ void ItemWidget::onFuncButtonClicked()
     }
     break;
     default:
+        qCDebug(views) << "Branch: default";
         break;
     }
+    qCDebug(views) << "ItemWidget::onFuncButtonClicked() finished";
 }
 
 
 void ItemWidget::onIconButtonClicked()
 {
+    qCDebug(views) << "ItemWidget::onIconButtonClicked() entered";
+
     /***add begin by ut001121 zhangmeng 20200924 判断移动事件来源 修复BUG48618***/
     if (m_moveSource) {
+        qCDebug(views) << "Branch: m_moveSource exists, returning";
         m_moveSource = nullptr;
         return ;
     }
@@ -246,36 +275,46 @@ void ItemWidget::onIconButtonClicked()
     // 判断类型执行操作
     switch (m_functType) {
     case ItemFuncType_Group:
+        qCDebug(views) << "Branch: ItemFuncType_Group";
         // 显示分组
-        qInfo() << "group show" << m_firstText;
+        qCInfo(views) << "group show" << m_firstText;
         // 第一个参数是分组名，第二个参数是当前是否有焦点
         emit groupClicked(m_firstText, m_isFocus);
         break;
     case ItemFuncType_Item:
+        qCDebug(views) << "Branch: ItemFuncType_Item";
         // 项被点击
-        qInfo() << "item clicked" << m_firstText;
+        qCInfo(views) << "item clicked" << m_firstText;
         emit itemClicked(m_firstText);
         break;
     default:
+        // qCDebug(views) << "Branch: default";
         break;
     }
+    qCDebug(views) << "ItemWidget::onIconButtonClicked() finished";
 }
 
 void ItemWidget::onFocusReback()
 {
+    qInfo() << "Focus returned to ItemWidget";
+
     setFocus();
 }
 
 void ItemWidget::onFocusOut(Qt::FocusReason type)
 {
+    qCDebug(views) << "Enter ItemWidget::onFocusOut";
     // Tab切出
-    if ((Qt::TabFocusReason == type) || (Qt::BacktabFocusReason == type))
+    if ((Qt::TabFocusReason == type) || (Qt::BacktabFocusReason == type)) {
+        qCDebug(views) << "Branch: Tab or BackTab focus reason";
         emit focusOut(type);
+    }
 
     if (Qt::ActiveWindowFocusReason == type) {
+        qCDebug(views) << "Branch: ActiveWindow focus reason";
         // 例如:super后返回都需要将焦点返回项
         setFocus();
-        qInfo() << "set focus back itemwidget";
+        qCInfo(views) << "set focus back itemwidget";
     }
     // 项
     if (type != Qt::OtherFocusReason && !m_isHover) {
@@ -284,6 +323,7 @@ void ItemWidget::onFocusOut(Qt::FocusReason type)
                 m_deleteButton->hide();
         }
     }
+    qCDebug(views) << "ItemWidget::onFocusOut finished";
 }
 
 /**
@@ -292,19 +332,23 @@ void ItemWidget::onFocusOut(Qt::FocusReason type)
  */
 void ItemWidget::updateSizeMode()
 {
+    qCDebug(views) << "Enter ItemWidget::updateSizeMode";
 #ifdef DTKWIDGET_CLASS_DSizeMode
     if (DGuiApplicationHelper::isCompactMode()) {
+        qCDebug(views) << "Branch: compact mode";
         m_iconLayout->setContentsMargins(s_ItemIconContentMarginsCompact);
         setFixedSize(220, s_ItemHeightCompact);
         setFont(m_firstline, DFontSizeManager::T6, ItemTextColor_Text);
         setFont(m_secondline, DFontSizeManager::T7, ItemTextColor_TextTips);
     } else {
+        qCDebug(views) << "Branch: normal mode";
         m_iconLayout->setContentsMargins(s_ItemIconContentMargins);
         setFixedSize(220, s_ItemHeight);
         setFont(m_firstline, DFontSizeManager::T7, ItemTextColor_Text);
         setFont(m_secondline, DFontSizeManager::T8, ItemTextColor_TextTips);
     }
 #endif
+    // qCDebug(views) << "ItemWidget::updateSizeMode finished";
 }
 
 void ItemWidget::initUI()
@@ -359,7 +403,7 @@ void ItemWidget::initUI()
     }
 
     // 功能键布局
-    // Todo (Yutao Meng): 建议删除键采用自定义图标，以免某些主题中没有合适的明暗色图标
+    // 删除键图标统一使用 edit-delete，保持明暗主题一致
     m_deleteButton->setIcon(QIcon::fromTheme("edit-delete"));
     m_deleteButton->setFlat(true);
     m_deleteButton->setFocusPolicy(Qt::NoFocus);
@@ -396,16 +440,15 @@ void ItemWidget::initUI()
 
     // 根据不同布局初始化界面
     updateSizeMode();
+    qCDebug(views) << "ItemWidget::initUI() finished";
 }
 
 void ItemWidget::initConnections()
 {
+    qCDebug(views) << "ItemWidget::initConnections() entered";
+
     // 颜色随主题变化
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &ItemWidget::slotThemeChange);
-    // 删除键被点击
-    connect(m_deleteButton, &DIconButton::clicked, this, [this] {
-        emit itemDelete(m_firstText, m_functType);
-    });
     // 功能键被点击
     connect(m_funcButton, &DIconButton::clicked, this, &ItemWidget::onFuncButtonClicked);
     // 焦点从小图标切出，但在控件上
@@ -414,32 +457,48 @@ void ItemWidget::initConnections()
     connect(m_funcButton, &IconButton::focusOut, this, &ItemWidget::onFocusOut);
     // 图标被点击
     connect(m_iconButton, &DIconButton::clicked, this, &ItemWidget::onIconButtonClicked);
+    // 删除按钮被点击
+    connect(m_deleteButton, &DIconButton::clicked, this, &ItemWidget::onDeleteButtonClicked);
+
+    qCDebug(views) << "ItemWidget::initConnections() finished";
+}
+void ItemWidget::onDeleteButtonClicked()
+{
+    qCDebug(views) << "ItemWidget::onDeleteButtonClicked() entered";
+
+    /***add begin by ut001121 zhangmeng 20200924 判断移动事件来源 修复BUG48618***/
+    if (m_moveSource) {
+        qCDebug(views) << "Branch: m_moveSource exists, returning";
+        m_moveSource = nullptr;
+        return ;
+    }
+    /***add end by ut001121***/
+
+    // 分组与项都允许删除
+    emit itemDelete(m_firstText, m_functType);
 }
 
 void ItemWidget::paintEvent(QPaintEvent *event)
 {
+    qCDebug(views) << "ItemWidget::paintEvent() entered";
+
     // 绘制文字长短
     QFont firstFont = m_firstline->font();
     QFont secondFont = m_secondline->font();
     // 限制文字长度,防止超出
-    QString firstText;
-    QString secondText;
-    if (!m_funcButton->isVisible()) {
-        firstText = Utils::getElidedText(firstFont, m_firstText, ITEMMAXWIDTH);
-        secondText = Utils::getElidedText(secondFont, m_secondText, ITEMMAXWIDTH);
-    } else {
-        firstText = Utils::getElidedText(firstFont, m_firstText, ITEMMAXWIDTH - m_funcButton->width());
-        secondText = Utils::getElidedText(secondFont, m_secondText, ITEMMAXWIDTH - m_funcButton->width());
-    }
+    QString firstText = Utils::getElidedText(firstFont, m_firstText, ITEMMAXWIDTH);
+    QString secondText = Utils::getElidedText(secondFont, m_secondText, ITEMMAXWIDTH);
     // 设置显示的文字
     m_firstline->setText(firstText);
     m_secondline->setText(secondText);
 
     FocusFrame::paintEvent(event);
+    qCDebug(views) << "ItemWidget::paintEvent() finished";
 }
 
-void ItemWidget::enterEvent(QEvent *event)
+void ItemWidget::enterEvent(EnterEvent *event)
 {
+    // qCDebug(views) << "Enter ItemWidget::enterEvent";
     // 编辑按钮现
     if (ItemFuncType_Item == m_functType || ItemFuncType_Group == m_functType) {
         m_funcButton->show();
@@ -447,12 +506,15 @@ void ItemWidget::enterEvent(QEvent *event)
     }
 
     FocusFrame::enterEvent(event);
+    // qCDebug(views) << "ItemWidget::enterEvent finished";
 }
 
 void ItemWidget::leaveEvent(QEvent *event)
 {
+    // qCDebug(views) << "Enter ItemWidget::leaveEvent";
     // 判断焦点是否是选中状态，不是的话，清除选中效果
     if (!m_isFocus && !m_funcButton->hasFocus()) {
+        // qCDebug(views) << "Branch: no focus and button has no focus";
         // 编辑按钮出
         if (ItemFuncType_Item == m_functType || ItemFuncType_Group == m_functType) {
             m_funcButton->hide();
@@ -461,29 +523,36 @@ void ItemWidget::leaveEvent(QEvent *event)
     }
 
     FocusFrame::leaveEvent(event);
+    // qCDebug(views) << "ItemWidget::leaveEvent finished";
 }
 
 void ItemWidget::mousePressEvent(QMouseEvent *event)
 {
+    // qCDebug(views) << "Enter ItemWidget::mousePressEvent";
     FocusFrame::mousePressEvent(event);
+    // qCDebug(views) << "ItemWidget::mousePressEvent finished";
 }
 
 void ItemWidget::mouseReleaseEvent(QMouseEvent *event)
 {
+    // qCDebug(views) << "Enter ItemWidget::mouseReleaseEvent";
     // 判断类型执行操作
     onItemClicked();
     // 捕获事件
     event->accept();
 
     FocusFrame::mouseReleaseEvent(event);
+    // qCDebug(views) << "ItemWidget::mouseReleaseEvent finished";
 }
 
 bool ItemWidget::eventFilter(QObject *watched, QEvent *event)
 {
+    // qCDebug(views) << "Enter ItemWidget::eventFilter";
     /***add begin by ut001121 zhangmeng 20200924 过滤并处理鼠标事件 修复BUG48618***/
 
     if (QEvent::MouseButtonPress == event->type()
             && Qt::MouseEventSynthesizedByQt == static_cast<QMouseEvent *>(event)->source()) {
+        qCDebug(views) << "Branch: MouseButtonPress";
         QMouseEvent *mouse = static_cast<QMouseEvent *>(event);
         //记录移动事件来源
         m_moveSource = watched;
@@ -494,14 +563,17 @@ bool ItemWidget::eventFilter(QObject *watched, QEvent *event)
     }
     if (QEvent::MouseButtonRelease == event->type()
             && Qt::MouseEventSynthesizedByQt == static_cast<QMouseEvent *>(event)->source()) {
+        qCDebug(views) << "Branch: MouseButtonRelease";
         //判断最大移动距离
         if (m_touchSlideMaxY <= COORDINATE_ERROR_Y) {
+            // qCDebug(views) << "Branch: slide distance within error range";
             //移动事件源为空,表示未曾移动过
             m_moveSource = nullptr;
         }
     }
     if (QEvent::MouseMove == event->type()
             && Qt::MouseEventSynthesizedByQt == static_cast<QMouseEvent *>(event)->source()) {
+        qCDebug(views) << "Branch: MouseMove";
         QMouseEvent *mouse = static_cast<QMouseEvent *>(event);
         //记录滑动最大距离
         m_touchSlideMaxY = qMax(m_touchSlideMaxY, qAbs(m_touchPressPosY - mouse->globalPos().y()));
@@ -512,27 +584,31 @@ bool ItemWidget::eventFilter(QObject *watched, QEvent *event)
 
 void ItemWidget::keyPressEvent(QKeyEvent *event)
 {
+    // qCDebug(views) << "Enter ItemWidget::keyPressEvent";
     switch (event->key()) {
     case Qt::Key_Right:
         // 点击键盘右键
-        qInfo() << "right key press";
+        qCInfo(views) << "right key press";
         rightKeyPress();
         break;
     case Qt::Key_Enter:
     case Qt::Key_Return:
     case Qt::Key_Space:
+        qCDebug(views) << "Branch: Key_Enter/Key_Return/Key_Space";
         // 项被点击执行
         onItemClicked();
         break;
     default:
+        // qCDebug(views) << "Branch: default key";
         FocusFrame::keyPressEvent(event);
         break;
     }
-
+    // qCDebug(views) << "ItemWidget::keyPressEvent finished";
 }
 
 void ItemWidget::focusInEvent(QFocusEvent *event)
 {
+    // qCDebug(views) << "Enter ItemWidget::focusInEvent";
     m_isFocus = true;
     if (ItemFuncType_Item == m_functType || ItemFuncType_Group == m_functType) {
         m_funcButton->show();
@@ -540,15 +616,19 @@ void ItemWidget::focusInEvent(QFocusEvent *event)
     }
 
     FocusFrame::focusInEvent(event);
+    // qCDebug(views) << "ItemWidget::focusInEvent finished";
 }
 
 void ItemWidget::focusOutEvent(QFocusEvent *event)
 {
+    // qCDebug(views) << "Enter ItemWidget::focusOutEvent";
     m_isFocus = false;
     // Tab切出
     Qt::FocusReason type = event->reason();
-    if (Qt::TabFocusReason == type || Qt::BacktabFocusReason == type)
+    if (Qt::TabFocusReason == type || Qt::BacktabFocusReason == type) {
+        // qCDebug(views) << "Branch: Tab or BackTab focus reason";
         emit focusOut(type);
+    }
 
     if (ItemFuncType_Item == m_functType || ItemFuncType_Group == m_functType) {
         // 编辑按钮也没焦点，则隐藏编辑按钮
@@ -558,34 +638,42 @@ void ItemWidget::focusOutEvent(QFocusEvent *event)
         }
     }
     FocusFrame::focusOutEvent(event);
+    // qCDebug(views) << "ItemWidget::focusOutEvent finished";
 }
 
 void ItemWidget::setFont(DLabel *label, DFontSizeManager::SizeType fontSize, ItemTextColor colorType)
 {
+    // qCDebug(views) << "Enter ItemWidget::setFont";
     setFontSize(label, fontSize);
     setFontColor(label, colorType);
+    // qCDebug(views) << "ItemWidget::setFont finished";
 }
 
 void ItemWidget::setFontSize(DLabel *label, DFontSizeManager::SizeType fontSize)
 {
+    // qCDebug(views) << "Enter ItemWidget::setFontSize";
     // 设置字体大小随系统变化
     DFontSizeManager::instance()->bind(label, fontSize);
+    // qCDebug(views) << "ItemWidget::setFontSize finished";
 }
 
 void ItemWidget::setFontColor(DLabel *label, ItemTextColor colorType)
 {
+    qCDebug(views) << "Enter ItemWidget::setFontColor";
     DPalette fontPalette = DPaletteHelper::instance()->palette(label);
     QColor color = getColor(colorType);
     if (color.isValid()) {
+        qCDebug(views) << "Branch: color is valid";
         fontPalette.setBrush(DPalette::Text, color);
         label->setPalette(fontPalette);
     } else {
-        qInfo() << __FUNCTION__ << "can't get text color";
+        qCWarning(views)  << "Can't get text color";
     }
 }
 
 QColor ItemWidget::getColor(ItemTextColor colorType)
 {
+    qCDebug(views) << "Enter ItemWidget::getColor";
     // 获取标准颜色
     DGuiApplicationHelper *appHelper = DGuiApplicationHelper::instance();
     DPalette textPalette = appHelper->standardPalette(appHelper->themeType());
@@ -593,15 +681,17 @@ QColor ItemWidget::getColor(ItemTextColor colorType)
     QColor color;
     switch (colorType) {
     case ItemTextColor_Text: {
+        qCDebug(views) << "Branch: ItemTextColor_Text";
         color =  textPalette.color(DPalette::Text);
     }
     break;
     case ItemTextColor_TextTips: {
+        qCDebug(views) << "Branch: ItemTextColor_TextTips";
         color =  textPalette.color(DPalette::TextTips);
     }
     break;
     default:
-        qInfo() << "item widget text unknow color type!" << colorType;
+        qCInfo(views) << "item widget text unknow color type!" << colorType;
         break;
     }
     return color;
@@ -609,28 +699,35 @@ QColor ItemWidget::getColor(ItemTextColor colorType)
 
 void ItemWidget::rightKeyPress()
 {
+    qCDebug(views) << "Enter ItemWidget::rightKeyPress";
     switch (m_functType) {
     case ItemFuncType_Group: {
+        qCDebug(views) << "Branch: ItemFuncType_Group";
         // 显示分组
-        qInfo() << "group show" << m_firstText;
+        qCInfo(views) << "group show" << m_firstText;
         emit groupClicked(m_firstText, true);
     }
     break;
     case ItemFuncType_Item:
+        qCDebug(views) << "Branch: ItemFuncType_Item";
         // 编辑按钮获得焦点
-        qInfo() << "item get focus" << m_firstText;
+        qCInfo(views) << "item get focus" << m_firstText;
         m_funcButton->show();
         m_funcButton->setFocus();
         break;
     default:
+        qCDebug(views) << "Branch: default";
         break;
     }
+    qCDebug(views) << "ItemWidget::rightKeyPress finished";
 }
 
 void ItemWidget::onItemClicked()
 {
+    qCDebug(views) << "Enter ItemWidget::onItemClicked";
     /***add begin by ut001121 zhangmeng 20200924 判断移动事件来源 修复BUG48618***/
     if (m_moveSource) {
+        qCDebug(views) << "Branch: m_moveSource exists, returning";
         m_moveSource = nullptr;
         return ;
     }
@@ -638,27 +735,32 @@ void ItemWidget::onItemClicked()
 
     switch (m_functType) {
     case ItemFuncType_Group:
+        qCDebug(views) << "Branch: ItemFuncType_Group";
         // 显示分组
-        qInfo() << "group show" << m_firstText;
+        qCInfo(views) << "group show" << m_firstText;
         // 第一个参数是分组名，第二个参数是当前是否有焦点
         emit groupClicked(m_firstText, m_isFocus);
         break;
     case ItemFuncType_Item:
+        qCDebug(views) << "Branch: ItemFuncType_Item";
         // 项被点击
-        qInfo() << "item clicked" << m_firstText;
+        qCInfo(views) << "item clicked" << m_firstText;
         emit itemClicked(m_firstText);
         break;
     case ItemFuncType_UngroupedItem:
         m_checkBox->setChecked(!m_checkBox->isChecked());
         break;
-    default:
-        break;
     }
+    qCDebug(views) << "ItemWidget::onItemClicked finished";
 }
 
 void ItemWidget::slotThemeChange(DGuiApplicationHelper::ColorType themeType)
 {
+    qCDebug(views) << "Enter ItemWidget::slotThemeChange";
     Q_UNUSED(themeType);
     setFontColor(m_firstline, ItemTextColor_Text);
     setFontColor(m_secondline, ItemTextColor_TextTips);
+    // 主题变化时统一使用 edit-delete 图标
+    m_deleteButton->setIcon(QIcon::fromTheme("edit-delete"));
+    qCDebug(views) << "ItemWidget::slotThemeChange finished";
 }
