@@ -1,5 +1,5 @@
 // Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -16,6 +16,7 @@
 #define ITEMWIDGET_H
 // custom
 #include "focusframe.h"
+#include "qtcompat.h"
 
 // dtk
 //#include <DFrame>
@@ -25,7 +26,7 @@
 #include <DGuiApplicationHelper>
 #include <DFontSizeManager>
 #include <DPalette>
-#include <DApplicationHelper>
+#include <DPaletteHelper>
 // qt
 #include <QVBoxLayout>
 #include <QHBoxLayout>
@@ -151,6 +152,10 @@ public slots:
      * @author ut000610 戴正文
      */
     void onIconButtonClicked();
+    /**
+     * @brief 处理删除按钮点击，发射删除信号
+     */
+    void onDeleteButtonClicked();
     /**
      * @brief 功能键丢失焦点，当前窗口获得焦点
      * @author ut000610 戴正文
@@ -207,7 +212,7 @@ protected:
      * @author ut000610 戴正文
      * @param event 事件
      */
-    void enterEvent(QEvent *event) override;
+    void enterEvent(EnterEvent *event) override;
     /**
      * @brief 移出，编辑按钮消失
      * @author ut000610 戴正文
